=======
History
=======

0.1.0 (2018-04-11)
------------------

* First release on PyPI.

0.1.1 (2018-04-15)
------------------

* Syntax, semantics and parsing support for the following formal languages:
    * Propositional Logic;
    * Linear Dynamic Logic on Finite Traces;
* Conversion from LDLf formula to NFA, DFA and DFA on-the-fly

0.1.3 (2018-04-20)
------------------

* Support for LTLf formulas and conversion into NFA, DFA and DFA on-the-fly
